import { EnvelopeIcon, PhoneIcon } from "@heroicons/react/24/solid";
import { GlobalContext } from "pages/_app";
import { Page } from "payload-types";
import { createElement, ForwardRefExoticComponent, SVGProps, useContext } from "react";

import { MARGIN_BOTTOM } from "styles/constants";

import { joinClassNames } from "utils/helper";

type CardProps = {
  title: string;
  icon: ForwardRefExoticComponent<SVGProps<SVGSVGElement>>;
  value: string;
};

const Card = ({ title, icon, value }: CardProps) => {
  return (
    <div className="bg-white p-2 lg:p-4 rounded-xl shadow h-full">
      <div className="p-16 bg-primary-500 flex flex-col justify-center items-center text-white bg-[url('/images/layered-waves-haikei.svg')] bg-cover rounded-xl h-full">
        {createElement(icon, { className: "h-10 w-10" })}
        <div className="mt-8 text-center font-display">
          <p className="text-3xl mb-4 tracking-wider">{title}</p>
          <p className="text-2xl tracking-wider" dangerouslySetInnerHTML={{ __html: value }}></p>
        </div>
      </div>
    </div>
  );
};

type ContactSectionBlock = Extract<
  Extract<Page["layout"][number], { blockType: "container" }>["layout"][number],
  { blockType: "contactSection" }
>;

const ContactSection = ({ marginBottom }: ContactSectionBlock) => {
  const { contactDetails } = useContext(GlobalContext);
  return (
    <div
      className={joinClassNames(
        "grid md:grid-cols-2 gap-8 w-full",
        marginBottom && MARGIN_BOTTOM[marginBottom]
      )}
    >
      <Card title="E-mailová adresa" icon={EnvelopeIcon} value={contactDetails.emailAddress} />
      <Card title="Telefonní číslo" icon={PhoneIcon} value={contactDetails.telephoneNumber} />
    </div>
  );
};

export default ContactSection;
