import Image from "next/image";
import { Page } from "payload-types";

import { MARGIN_BOTTOM } from "styles/constants";

import { joinClassNames } from "utils/helper";

type DividerBlock = Omit<
  Extract<
    Extract<Page["layout"][number], { blockType: "container" }>["layout"][number],
    { blockType: "divider" }
  >,
  "blockType"
>;

const Divider = ({ type, marginBottom }: DividerBlock) => {
  if (type === "graphical") {
    return (
      <div className={joinClassNames("bg-gray-100", MARGIN_BOTTOM[marginBottom])}>
        <div className="max-w-5xl mx-auto h-16 overflow-hidden relative w-full">
          <Image
            src="/images/layered-waves-2-haikei.svg"
            alt="Oddělovač"
            className="w-full object-cover object-top"
            fill
          />
        </div>
      </div>
    );
  }

  if (type === "simple") {
    return (
      <div
        className={joinClassNames(
          "flex max-w-5xl h-[1px] w-full items-center space-x-8",
          MARGIN_BOTTOM[marginBottom]
        )}
      >
        <div className="w-full border-t"></div>
        <Image
          src="/icons/sun.svg"
          width={0}
          height={0}
          alt="Ikona slunce"
          className="h-12 w-full"
        />
        <div className="w-full border-t"></div>
      </div>
    );
  }

  return (
    <div className={joinClassNames("bg-gray-100", MARGIN_BOTTOM[marginBottom])}>
      <div className="max-w-5xl mx-auto h-16 overflow-hidden relative w-full">
        <Image
          src="/images/layered-waves-2-haikei.svg"
          alt="Oddělovač"
          className="w-full object-cover object-top"
          fill
        />
      </div>
    </div>
  );
};

export default Divider;
