import Image from "next/image";
import { useRouter } from "next/router";
import { Employee, Media, Page } from "payload-types";

import { MARGIN_BOTTOM } from "styles/constants";

import { createImageUrl } from "utils/helper";

type EmployeeBlock = Extract<
  Extract<Page["layout"][number], { blockType: "container" }>["layout"][number],
  { blockType: "employeesBlock" }
>;

const Employees = ({ employees, marginBottom }: EmployeeBlock) => {
  const router = useRouter();
  const mainEmployee = (employees as Employee[]).filter(
    (employee) => employee.mainEmployee === true
  );
  const otherEmployees = (employees as Employee[]).filter(
    (employee) => employee.mainEmployee != true
  );

  const Employee = ({ data }) => {
    if (!data.showEmployee) return null;
    return (
      <div
        className="flex flex-col space-y-3 items-center text-center hover:scale-105 transition-transform cursor-pointer"
        onClick={() => router.push(`/employee/${data.slug}`)}
      >
        <Image
          src={
            data.image
              ? createImageUrl((data.image as Media).url)
              : "/images/avatar-placeholder.png"
          }
          width={data.image ? data.image?.width : 360}
          height={data.image ? data.image?.height : 360}
          alt={data.name}
          className="h-24 w-24 border-2 border-primary-600 p-1 rounded-full object-cover"
        />
        <div className="flex flex-col space-y-2">
          <p className="font-display text-4xl text-primary-600">{data.name}</p>
          <p className=" text-gray-600">{data.position}</p>
        </div>
      </div>
    );
  };

  return (
    <div className={MARGIN_BOTTOM[marginBottom]}>
      <div className="border-b border-gray-300 pb-16 mb-16 grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-2 gap-16">
        {mainEmployee.map((employee: Employee, index) => (
          <Employee data={employee} key={index} />
        ))}
      </div>
      <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 gap-16">
        {otherEmployees.map((employee: Employee, index) => (
          <Employee data={employee} key={index} />
        ))}
      </div>
    </div>
  );
};

export default Employees;
