import { Disclosure, Transition } from "@headlessui/react";
import { ChevronUpIcon } from "@heroicons/react/20/solid";
import { motion } from "framer-motion";
import { Page } from "payload-types";

import { MARGIN_BOTTOM } from "styles/constants";

import { animateFromLeft, joinClassNames } from "utils/helper";

type FaqBlock = Extract<
  Extract<Page["layout"][number], { blockType: "container" }>["layout"][number],
  { blockType: "faq" }
>;

const Faq = ({ questions, marginBottom }: FaqBlock) => {
  return (
    <motion.div
      className={joinClassNames(
        "w-full rounded-lg bg-primary-600 p-4 shadow",
        MARGIN_BOTTOM[marginBottom]
      )}
      {...animateFromLeft}
    >
      {questions.map((item, index) => (
        <Disclosure as="div" className="mt-2 bg-white rounded-lg overflow-hidden" key={index}>
          {({ open }) => (
            <>
              <Disclosure.Button
                className={joinClassNames(
                  "flex w-full justify-between px-6 py-4 text-left text-xl tracking-wider text-gray-600 hover:bg-gray-100 focus:outline-none focus-visible:ring focus-visible:ring-primary-500 focus-visible:ring-opacity-75 font-display transition-colors",
                  open && "border-b"
                )}
              >
                <span>{item.title}</span>
                <ChevronUpIcon
                  className={`${open ? "rotate-180 transform" : ""} h-5 w-5 text-gray-600`}
                />
              </Disclosure.Button>
              <Transition
                enter="transition duration-100 ease-out"
                enterFrom="transform scale-95 opacity-0"
                enterTo="transform scale-100 opacity-100"
                leave="transition duration-75 ease-out"
                leaveFrom="transform scale-100 opacity-100"
                leaveTo="transform scale-95 opacity-0"
              >
                <Disclosure.Panel className="px-6 pt-4 pb-8 text-gray-600">
                  {item.content}
                </Disclosure.Panel>
              </Transition>
            </>
          )}
        </Disclosure>
      ))}
    </motion.div>
  );
};

export default Faq;
