import Image from "next/image";
import Link from "next/link";
import { GlobalContext } from "pages/_app";
import { Media, Page, Post } from "payload-types";
import { useContext } from "react";

import { createImageUrl } from "utils/helper";

import { Brand } from "components/Brand";
import { SocialLink } from "components/SocialLink";

const Footer = () => {
  const { footer, socials } = useContext(GlobalContext);
  return (
    <footer className="bg-gray-100 p-2 py-8 lg:py-16">
      <div className="p-2 lg:p-4 bg-white max-w-7xl m-auto rounded-lg lg:rounded-2xl shadow-xl">
        <div className="relative w-full bg-cover overflow-hidden bg-primary-600 rounded-lg lg:rounded-2xl">
          <div className="w-full flex flex-col bg-cover">
            <div className="flex flex-col lg:flex-row mb-12 lg:mb-0 px-8 lg:px-20 pt-12 lg:py-16 gap-8 lg:gap-48">
              {footer?.columns?.map((item, index) => (
                <div key={index}>
                  <p className="text-white text-2xl lg:text-3xl tracking-wider font-display mb-6">
                    {item.title}
                  </p>
                  <ul className="space-y-4 font-display tracking-wider text-xl lg:text-2xl text-white font-light">
                    {item.navItems.map(
                      (item, index) =>
                        item && (
                          <li key={index}>
                            <Link
                              href={
                                item.link.type === "reference"
                                  ? (item.link.reference?.value as Page | Post).slug
                                  : item.link.url
                              }
                              className="inline-flex items-center group"
                              target={item.link.newTab ? "_blank" : "_self"}
                              rel={item.link.newTab && "noopener"}
                            >
                              {(item.link.icon as Media)?.url && (
                                <Image
                                  src={createImageUrl((item.link.icon as Media).url)}
                                  alt={(item.link.icon as Media).alt}
                                  className="mr-4 h-6 w-6 text-white"
                                  width="0"
                                  height="0"
                                  sizes="100vw"
                                />
                              )}
                              <span className="group-hover:text-[#fdb813] transition-colors">
                                {item.link.label ||
                                  (item.link.reference?.value as Page | Post).title}
                              </span>
                            </Link>
                          </li>
                        )
                    )}
                  </ul>
                </div>
              ))}
            </div>
          </div>
          <div className="px-8 lg:px-20 py-6 lg:py-12 border-t-4 rounded-b-lg lg:rounded-b-xl relative overflow-hidden bg-primary-900">
            <div className="relative flex flex-col-reverse md:flex-row gap-8 items-start lg:items-center w-full z-20">
              <Brand size="md" />
              <div className="flex space-x-4 items-start md:ml-auto">
                {socials.showFacebook && (
                  <SocialLink
                    href={socials.facebookUrl}
                    icon={{ src: "/icons/facebook.svg", alt: "Facebook" }}
                    label="Facebook"
                  />
                )}
                {socials.showInstagram && (
                  <SocialLink
                    href={socials.instagramUrl}
                    icon={{ src: "/icons/instagram.svg", alt: "Instagram" }}
                    label="Instagram"
                  />
                )}
                {socials.showTwitter && (
                  <SocialLink
                    href={socials.twitterUrl}
                    icon={{ src: "/icons/twitter.svg", alt: "Twitter" }}
                    label="Twutter"
                  />
                )}
                {socials.showLinkedIn && (
                  <SocialLink
                    href={socials.linkedInUrl}
                    icon={{ src: "/icons/linkedin-in.svg", alt: "LinkedIn" }}
                    label="LinkedIn"
                  />
                )}
              </div>
            </div>
          </div>
        </div>
      </div>
    </footer>
  );
};

export default Footer;
