import { Bars3Icon } from "@heroicons/react/24/solid";
import { motion } from "framer-motion";
import Image from "next/image";
import { GlobalContext } from "pages/_app";
import { Media, Page } from "payload-types";
import { Fragment, useContext, useState } from "react";

import { animateFromLeft } from "utils/helper";

import { Menu } from "components/Menu";
import { Navigation } from "components/Navigation";
import { RenderBlocks } from "components/RenderBlocks";

type HeroBlock = Extract<Page["layout"][number], { blockType: "hero" }> & {
  image: Media;
};

const Hero = ({ showNavigation, showLogo, subtitle, layout, image }: HeroBlock) => {
  const { header } = useContext(GlobalContext);
  const [open, setOpen] = useState<boolean>(false);
  return (
    <div className="relative">
      {showNavigation && (
        <Fragment>
          <div className="hidden relative z-20 lg:block mx-auto max-w-5xl py-8 text-white">
            <Navigation items={header.items} />
          </div>
          <Menu open={open} setOpen={setOpen} items={header.items} />
        </Fragment>
      )}
      <motion.div
        className="relative z-10 flex h-full flex-col items-center justify-center text-center text-white py-32 xl:py-48"
        {...animateFromLeft}
      >
        {showLogo && (
          <Image
            src={image.url}
            alt={image.alt}
            width={image.width}
            height={image.height}
            className="h-16 sm:h-20 md:h-24 lg:mb-12 xl:mb-12"
          />
        )}

        <h1 className="mb-16 font-display tracking-wider text-2xl sm:text-3xl lg:text-4xl min-w-[10rem]">
          {subtitle}
        </h1>
        <div className="flex space-x-4">
          <RenderBlocks blocks={layout} />
        </div>
      </motion.div>
      <div className="absolute inset-0 h-full w-full bg-black">
        <video autoPlay muted loop className="h-full w-full object-cover opacity-30">
          <source src="/images/video-8.mp4" />
        </video>
      </div>
      <div className="lg:hidden absolute right-4 top-8 z-50 flex flex-col items-center space-y-4">
        <button onClick={() => setOpen(!open)}>
          <Bars3Icon className="h-8 w-8 text-white" />
        </button>
      </div>
    </div>
  );
};

export default Hero;
