import { WIDTH } from "./style";
import { motion } from "framer-motion";
import NextImage from "next/image";
import { Media, Page } from "payload-types";

import { animateOpacity, createImageUrl, joinClassNames } from "utils/helper";

type ImageBlock = Omit<
  Extract<
    Extract<Page["layout"][number], { blockType: "container" }>["layout"][number],
    { blockType: "image" }
  > & { image: Media },
  "blockType"
>;

const Image = ({ image, caption, showCaption, width, setPriority }: ImageBlock) => {
  return (
    <motion.figure {...animateOpacity} className={WIDTH[width]}>
      <NextImage
        src={createImageUrl(image.url)}
        height={image.height}
        width={image.width}
        priority={setPriority}
        alt={image.alt}
        className={joinClassNames("w-full rounded-md mb-4 text-gray-600")}
      />
      {showCaption && (
        <figcaption
          className={joinClassNames(
            "text-center font-display tracking-wider text-lg text-gray-600"
          )}
        >
          {caption}
        </figcaption>
      )}
    </motion.figure>
  );
};

export default Image;
