import Image from "next/image";
import { Media } from "payload-types";
import { useEffect, useState } from "react";

import { createImageUrl } from "utils/helper";

import { RenderContent } from "components/RenderContent";

const OldReference = ({ references }: any) => {
  const [currentIndex, setCurrentIndex] = useState(0);

  useEffect(() => {
    const interval = setTimeout(() => {
      setCurrentIndex((currentIndex + 1) % references.length);
    }, 7500);
    return () => clearTimeout(interval);
  }, [currentIndex, references]);

  return (
    <div className="flex flex-col items-start md:flex-row">
      <div className="relative shadow-lg bg-white p-2 lg:p-4 rounded-xl">
        <div className="bg-primary-600 p-6 rounded-xl">
          <div className="relative w-72 h-72 mb-8">
            <Image
              fill
              className="object-cover rounded-lg"
              src={createImageUrl((references[currentIndex].image as Media).url)}
              alt={references[currentIndex].alt}
              sizes="(max-width: 768px) 80vw,
                (max-width: 1200px) 33vw,
                20vw"
            />
          </div>
          <div className="text-center text-white">
            <p className="font-display text-3xl mb-2">{references[currentIndex].name}</p>
            <p>{references[currentIndex].position}</p>
          </div>
        </div>
      </div>
      <div className="md:w-8/12 grow-0">
        <div className="mt-8">
          <p className="font-display text-4xl text-gray-600 mb-4 inline-block pl-8 pt-8 border-t-8 border-primary-600">
            Hodnocení klienta
          </p>
          <div className="pl-8">
            <div className="text-gray-600 text-justify">
              <RenderContent richText={references[currentIndex].review} />
            </div>
            <div className="flex space-x-4 mt-8">
              {references.map((_, idx) => (
                <div
                  className="relative h-5 w-5 bg-primary-500 rounded-full cursor-pointer"
                  onClick={() => {
                    setCurrentIndex(idx);
                  }}
                  key={idx}
                >
                  {currentIndex === idx && (
                    <div className="absolute h-2.5 w-2.5 bg-white left-1/2 -translate-x-1/2 top-1/2 -translate-y-1/2 rounded-full" />
                  )}
                </div>
              ))}
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default OldReference;
