import { CheckBadgeIcon } from "@heroicons/react/24/solid";
import Image from "next/image";
import { Client, ClientReference, Media } from "payload-types";
import { useEffect, useState } from "react";

import Blockquote from "components/Blockquote";
import { RenderContent } from "components/RenderContent";

type Props = {
  data: ClientReference;
};

const Reference = ({ data }: Props) => {
  const [currentIndex, setCurrentIndex] = useState(0);
  useEffect(() => {
    const interval = setTimeout(() => {
      setCurrentIndex((currentIndex + 1) % data.images.length);
    }, 7500);
    return () => clearTimeout(interval);
  }, [currentIndex]);

  useEffect(() => {
    setCurrentIndex(0);
  }, [data]);

  return (
    <div className="flex flex-col lg:flex-row w-full space-y-4 lg:space-x-16">
      {data.enableImages && (
        <div className="lg:w-5/12 relative">
          <Image
            src={(data?.images[currentIndex]?.image as Media)?.url}
            className="w-full h-96 object-cover mb-4"
            width={720}
            height={1280}
            alt="Test"
          />
          <div className="flex space-x-2">
            {data.images.map((_, index) => (
              <div
                className="relative h-5 w-5 bg-primary-500 rounded-full cursor-pointer"
                onClick={() => {
                  setCurrentIndex(index);
                }}
                key={index}
              >
                {currentIndex === index && (
                  <div className="absolute h-2.5 w-2.5 bg-white left-1/2 -translate-x-1/2 top-1/2 -translate-y-1/2 rounded-full" />
                )}
              </div>
            ))}
          </div>
        </div>
      )}
      <div className={data.enableImages ? "lg:w-7/12" : "w-full"}>
        <div className="text-2xl mb-8 text-gray-600 not-prose">
          <RenderContent richText={data.title} prose={false} />
        </div>
        <ul className="max-w-md space-y-1 text-gray-600 list-inside dark:text-gray-400 mb-8">
          {data.points.map((point, index) => (
            <li className="flex items-center" key={index}>
              <CheckBadgeIcon className="text-primary-600 flex-shrink-0 mr-4" height={32} />
              <RenderContent richText={point.text} />
            </li>
          ))}
        </ul>
        <Blockquote>
          <RenderContent richText={data.review} />
        </Blockquote>
        <div className="flex items-center space-x-4">
          <Image
            src={((data.client as Client).image as Media).url}
            width={128}
            height={128}
            alt="Alt"
            className="rounded-full w-24 h-24 object-cover"
          />
          <div>
            <p className="text-lg font-bold text-gray-600">{(data.client as Client).name}</p>
            <p>{(data.client as Client).position}</p>
          </div>
        </div>
      </div>
    </div>
  );
};

export default Reference;
