import { ChevronLeftIcon, ChevronRightIcon } from "@heroicons/react/24/solid";
import { ClientReference, Page } from "payload-types";
import { useEffect, useState } from "react";

import { Reference } from "components/Reference";

type ReferencesBlock = Extract<
  Extract<Page["layout"][number], { blockType: "container" }>["layout"][number],
  { blockType: "referenceBlock" }
>;

const References = ({ references }: ReferencesBlock) => {
  const [currentIndex, setCurrentIndex] = useState(0);
  const currentReference = references[currentIndex] as ClientReference;

  useEffect(() => {
    const interval = setTimeout(() => {
      setCurrentIndex((currentIndex + 1) % references.length);
    }, 7500);
    return () => clearTimeout(interval);
  }, [currentIndex, references]);

  const handleStepMinus = () => {
    if (currentIndex > 0) {
      setCurrentIndex((currentIndex - 1) % references.length);
    }
  };

  const handleStepPlus = () => {
    if (currentIndex < references.length - 1) {
      setCurrentIndex((currentIndex + 1) % references.length);
    }
  };

  return (
    <div className="relative">
      {currentIndex > 0 && (
        <button
          className="absolute top-1/2 translate-y-1/2 -left-32 text-gray-400 hover:text-gray-600 transition-colors"
          onClick={handleStepMinus}
        >
          <ChevronLeftIcon className="h-8" />
        </button>
      )}
      <Reference data={currentReference} />
      {currentIndex < references.length - 1 && (
        <button
          className="absolute top-1/2 translate-y-1/2 -right-32 text-gray-400 hover:text-gray-600 transition-colors"
          onClick={handleStepPlus}
        >
          <ChevronRightIcon className="h-8" />
        </button>
      )}
    </div>
  );
};

export default References;
