import { ReactNode } from "react";
import { FieldValues, UseFormRegister } from "react-hook-form";

type Props = {
  label: string;
  register: UseFormRegister<FieldValues>;
  name: string;
  children: ReactNode | ReactNode[];
};

const Select = ({ label, register, name, children }: Props) => (
  <div className="relative">
    <label
      htmlFor={name}
      className="group absolute top-4 left-2.5 z-10 origin-[0] -translate-y-4 scale-75 transform text-xl tracking-wider font-display text-gray-500 duration-300 peer-placeholder-shown:translate-y-0 peer-placeholder-shown:scale-100 peer-focus:-translate-y-4 peer-focus:scale-75 peer-focus:text-primary-600 dark:text-gray-400 peer-focus:dark:text-primary-500"
    >
      {label}
    </label>
    <select
      className="peer block w-full appearance-none rounded-t-lg border-0 border-b-2 border-gray-300 bg-gray-50 px-2.5 pb-2.5 pt-8 text-sm text-gray-900 focus:border-primary-600 focus:outline-none focus:ring-0 dark:border-gray-600 dark:bg-gray-700 dark:text-white dark:focus:border-primary-500"
      {...register(name)}
      name={name}
      id={name}
    >
      {children}
    </select>
  </div>
);

const Option = ({ value, children }) => <option value={value}>{children}</option>;

Select.Option = Option;
export default Select;
