import Image from "next/image";
import { Media, Page } from "payload-types";

import { MARGIN_BOTTOM } from "styles/constants";

import { createImageUrl, joinClassNames } from "utils/helper";

import { RenderContent } from "components/RenderContent";

type ShowcaseBlock = Extract<
  Extract<Page["layout"][number], { blockType: "container" }>["layout"][number],
  { blockType: "showcase" }
>;

const Showcase = ({ items, marginBottom }: ShowcaseBlock) => {
  return (
    <div
      className={joinClassNames(
        "grid grid-prod lg:grid-cols-2 mb-16",
        marginBottom && MARGIN_BOTTOM[marginBottom]
      )}
    >
      {items.map((item, index) => (
        <div
          className="flex flex-col lg:flex-row items-start lg:items-center lg:border-r border-b lg:odd:pl-0 lg:even:border-r-0 px-2 py-8 lg:p-12 space-y-8 lg:space-x-16"
          key={index}
        >
          <Image
            src={createImageUrl((item.icon as Media).url)}
            alt={(item.icon as Media).alt}
            width={(item.icon as Media).width}
            height={(item.icon as Media).height}
            className="h-16"
          />
          <div>
            <p className="text-2xl font-display tracking-wider text-gray-600">{item.title}</p>
            <div className="text-gray-500">
              <RenderContent richText={item.description} />
            </div>
          </div>
        </div>
      ))}
    </div>
  );
};

export default Showcase;
