import { motion } from "framer-motion";
import { Page } from "payload-types";
import { useState } from "react";

import { MARGIN_BOTTOM } from "styles/constants";

import { animateOpacity, joinClassNames } from "utils/helper";

import { Heading } from "components/Heading";
import { RenderContent } from "components/RenderContent";

type TimelineBlock = Extract<
  Extract<Page["layout"][number], { blockType: "container" }>["layout"][number],
  { blockType: "timeline" }
>;

const Timeline = ({ items, marginBottom }: TimelineBlock) => {
  const [show, setShow] = useState(false);
  return (
    <div className={joinClassNames(marginBottom && MARGIN_BOTTOM[marginBottom])}>
      <div className={joinClassNames(!show && "h-[26rem] fade", "relative pl-6 overflow-y-hidden")}>
        <div className="border-l border-gray-300 ">
          {items.map((item, index) => (
            <motion.div className="flex min-h-[9.5rem]" key={index} {...animateOpacity}>
              <div className="shrink-0 bg-gray-100 w-12 h-12 -ml-6 mr-3 flex justify-center items-center font-display text-4xl text-primary-600">
                {index + 1}
              </div>
              <div className="mt-0.5 ml-4 mb-6">
                <Heading text={item.title} type="h4" as="p" />
                <div className="text-gray-500 mb-3">
                  <RenderContent richText={item.description} />
                </div>
              </div>
            </motion.div>
          ))}
        </div>
        {/* <div class="absolute top-0 left-0 w-full h-full bg-gradient-to-b from-transparent to-gray-100"></div> */}
      </div>
      <div className="mt-8">
        <button
          className="relative group inline-block border border-primary-600 bg-primary-600 hover:bg-primary-700 transition-colors px-3 py-1 text-white font-display text-lg shadow uppercase tracking-wider rounded-sm"
          onClick={() => setShow(!show)}
        >
          {!show ? "Zobrazit celé" : "Skrýt"}
        </button>
      </div>
    </div>
  );
};

export default Timeline;
