import { GetStaticProps } from "next";
import { NextSeo } from "next-seo";
import { fetchPage, fetchPageSlugs } from "queries/pages";
import { Fragment } from "react";

import { LayoutMain } from "components/LayoutMain";
import { PreviewBar } from "components/PreviewBar";
import { RenderBlocks } from "components/RenderBlocks";

const Slug = ({ page, preview }) => {
  return (
    <Fragment>
      <NextSeo title={page.meta.title} description={page.meta.description} />
      {preview && <PreviewBar />}
      <RenderBlocks blocks={page.layout} />
    </Fragment>
  );
};

export const getStaticProps: GetStaticProps = async ({ params, preview = false }) => {
  const page = await fetchPage(params.slug as string, preview);
  if (!page) {
    return {
      notFound: true,
    };
  }

  return {
    props: { page, preview },
  };
};

export const getStaticPaths = async () => {
  const slugs = await fetchPageSlugs();
  return {
    paths: slugs?.map((slug: string) => `/${slug}`),
    fallback: "blocking",
  };
};

Slug.layout = LayoutMain;
export default Slug;
