import { GetStaticProps } from "next";
import { NextSeo } from "next-seo";
import { Page } from "payload-types";
import { fetchWebsiteSettings } from "queries/globals";
import { fetchPage } from "queries/pages";
import { Fragment } from "react";

import { LayoutHero } from "components/LayoutHero";
import { PreviewBar } from "components/PreviewBar";
import { RenderBlocks } from "components/RenderBlocks";

const Index = ({ page, preview }) => {
  return (
    <Fragment>
      <NextSeo title={page.meta.title} description={page.meta.description} />
      {preview && <PreviewBar />}
      <RenderBlocks blocks={page.layout} />
    </Fragment>
  );
};

export const getStaticProps: GetStaticProps = async ({ preview = false }) => {
  const websiteSettings = await fetchWebsiteSettings();
  const page = await fetchPage((websiteSettings.mainPage.value as Page).slug, preview);

  if (!page) {
    return {
      notFound: true,
    };
  }

  return {
    props: { page, preview },
  };
};

Index.layout = LayoutHero;
export default Index;
