import { regeneratePage } from "../utilities/regeneratePage";
import { CollectionConfig } from "payload/types";

export const ClientReferences: CollectionConfig = {
  slug: "clientReferences",
  labels: {
    singular: "Reference",
    plural: "Reference",
  },
  access: {
    read: () => {
      return true;
    },
  },
  hooks: {
    afterChange: [
      ({ req: { payload } }) => {
        regeneratePage({
          payload,
        });
      },
    ],
  },
  fields: [
    {
      name: "title",
      label: "Titulek reference",
      type: "richText",
      required: true,
    },
    {
      name: "enableImages",
      type: "checkbox",
      label: "Povolit nahrávání obrázků",
      defaultValue: false,
    },
    {
      name: "images",
      type: "array",
      label: "Obrázky",
      labels: {
        singular: "Obrázek",
        plural: "Obrázky",
      },
      fields: [
        {
          name: "image",
          label: "Obrázek",
          type: "upload",
          relationTo: "media",
          required: true,
        },
      ],
      admin: {
        condition: (data) => {
          if (data.enableImages) {
            return true;
          } else {
            return false;
          }
        },
      },
    },
    {
      name: "client",
      label: "Klient",
      admin: {
        description: "Vyberte klienta, ke kterému se má recenze vztahovat",
      },
      type: "relationship",
      relationTo: "clients",
      hasMany: false,
      required: true,
      maxDepth: 10,
    },
    {
      name: "review",
      label: "Hodnocení",
      type: "richText",
      required: true,
    },
    {
      name: "points",
      type: "array",
      label: "Důležité body",
      labels: {
        singular: "Důležitý bod",
        plural: "Důležité body",
      },
      fields: [
        {
          name: "text",
          type: "richText",
          required: true,
        },
      ],
    },
  ],
};
