import { regeneratePage } from "../utilities/regeneratePage";
import path from "path";
import { CollectionConfig } from "payload/types";

const Media: CollectionConfig = {
  slug: "media",
  labels: {
    singular: "Médium",
    plural: "Média",
  },
  admin: {
    useAsTitle: "filename",
  },
  access: {
    read: () => {
      return true;
    },
    create: () => {
      return true;
    },
  },
  hooks: {
    afterDelete: [
      ({ req: { payload } }) => {
        regeneratePage({
          payload,
        });
      },
    ],
    afterChange: [
      ({ req: { payload } }) => {
        regeneratePage({
          payload,
        });
      },
    ],
  },
  upload: {
    adminThumbnail: "thumbnail",
    staticURL: "/media",
    staticDir: path.resolve(__dirname, "../../media"),
    mimeTypes: ["image/png", "image/jpeg", "image/svg+xml"],
    imageSizes: [
      {
        name: "thumbnail",
        width: 480,
        height: 320,
      },
      {
        name: "portrait",
        width: 768,
        height: 1024,
      },
      {
        name: "hero",
        width: 1920,
        height: 1080,
      },
    ],
  },
  fields: [
    {
      name: "alt",
      label: "Alternativní text",
      localized: true,
      type: "text",
      required: true,
    },
  ],
};

export default Media;
