import { BottomOverflow } from "../blocks/BottomOverflow";
import { Button } from "../blocks/Button";
import { Container } from "../blocks/Container";
import { Hero } from "../blocks/Hero";
import { slugField } from "../fields/slug";
import { deletePage } from "../utilities/deletePage";
import { formatPreviewURL } from "../utilities/formatPreviewUrl";
import { regeneratePage } from "../utilities/regeneratePage";
import removeLayout from "../utilities/removeLayout";
import type { CollectionConfig } from "payload/types";

export const Pages: CollectionConfig = {
  slug: "pages",
  labels: {
    singular: "Stránka",
    plural: "Stránky",
  },
  access: {
    read: () => {
      return true;
    },
  },
  hooks: {
    afterRead: [
      ({ doc }) => {
        return removeLayout(doc);
      },
    ],
    afterDelete: [
      ({ doc, req: { payload } }) => {
        deletePage({ doc, payload });
      },
    ],
    afterChange: [
      ({ req: { payload } }) => {
        regeneratePage({
          payload,
        });
      },
    ],
  },
  admin: {
    useAsTitle: "title",
    preview: (doc) => formatPreviewURL("pages", doc),
    defaultColumns: ["title", "slug", "createdAt", "updatedAt"],
  },
  versions: {
    drafts: true,
  },
  fields: [
    {
      name: "title",
      type: "text",
      required: true,
      label: "Název",
    },
    {
      type: "tabs",
      tabs: [
        {
          label: "Obsah stránky",
          fields: [
            {
              label: "Komponenta",
              labels: {
                singular: "Komponenta",
                plural: "Komponenty",
              },
              name: "layout",
              type: "blocks",
              blocks: [Container, Button, Hero, BottomOverflow],
            },
          ],
        },
      ],
    },
    slugField("title", { required: true }),
  ],
  endpoints: [
    {
      path: "/slugs",
      method: "get",
      handler: async (req, res, next) => {
        const { docs } = await req.payload.find({
          collection: "pages",
          pagination: false,
        });
        const slugs = docs.map((page) => page.slug);
        if (docs) {
          res.status(200).send(slugs);
        } else {
          res.status(404).send({ error: "not found" });
        }
      },
    },
    {
      path: "/all",
      method: "get",
      handler: async (req, res) => {
        const { docs } = await req.payload.find({
          collection: "pages",
          pagination: false,
        });
        if (docs) {
          res.status(200).send(docs);
        } else {
          res.status(404).send({ error: "not found" });
        }
      },
    },
  ],
};
