import "./styles.scss";
import type { DiskSpace } from "check-disk-space";
import React, { Fragment, useEffect, useState } from "react";

const baseClass = "before-dashboard";

export function formatBytes(bytes: number, decimals: number) {
  if (bytes == 0) return "0 Bytů";
  var k = 1024,
    dm = decimals || 2,
    sizes = ["Bytů", "KB", "MB", "GB", "TB", "PB", "EB", "ZB", "YB"],
    i = Math.floor(Math.log(bytes) / Math.log(k));
  return parseFloat((bytes / Math.pow(k, i)).toFixed(dm)) + " " + sizes[i];
}

const AfterDashboard: React.FC = () => {
  const [diskSpace, setDiskSpace] = useState<DiskSpace>(null);
  const [percentageWidth, setPercentageWidth] = useState<number>(null);

  const fetchDiskSpace = async () => {
    const res = await fetch(
      `${process.env.PAYLOAD_PUBLIC_SERVER_URL}/check-disk-space`
    );
    const data = await res.json();
    return data;
  };

  useEffect(() => {
    const set = async () => {
      const diskSpace = await fetchDiskSpace();
      setDiskSpace(diskSpace);
    };
    set();
  }, []);

  useEffect(() => {
    if (diskSpace) {
      const percentage = 100 - (diskSpace.free / diskSpace.size) * 100;
      setPercentageWidth(percentage);
    }
  }, [diskSpace]);

  return (
    <Fragment>
      <h3>Volné místo na disku</h3>
      {percentageWidth && (
        <div>
          <div className="progress">
            <div
              className="progress-bar"
              style={{ width: `${percentageWidth}%` }}
            ></div>
          </div>
          <div>{formatBytes(diskSpace.free, 0)} volného místa</div>
        </div>
      )}
    </Fragment>
  );
};

export default AfterDashboard;
