import deepMerge from "../../utilities/deepMerge";
import elements from "./elements";
import leaves from "./leaves";
import {
  RichTextElement,
  RichTextField,
  RichTextLeaf,
} from "payload/dist/fields/config/types";

type RichText = (
  overrides?: Partial<RichTextField>,
  additions?: {
    elements?: RichTextElement[];
    leaves?: RichTextLeaf[];
  }
) => RichTextField;

const richText: RichText = (
  overrides,
  additions = {
    elements: [],
    leaves: [],
  }
) =>
  deepMerge<RichTextField, Partial<RichTextField>>(
    {
      name: "richText",
      type: "richText",
      admin: {
        upload: {
          collections: {
            media: {
              fields: [
                {
                  type: "richText",
                  name: "caption",
                  label: "Caption",
                  admin: {
                    elements: [...elements],
                    leaves: [...leaves],
                  },
                },
                {
                  name: "width",
                  label: "Šířka obrázku",
                  type: "radio",
                  options: [
                    { label: "1/4 šířky", value: "1/4" },
                    { label: "1/3 šířky", value: "1/3" },
                    { label: "1/2 šířky", value: "1/2" },
                    { label: "2/3 šířky", value: "2/3" },
                    { label: "3/4 šířky", value: "3/4" },
                    { label: "Plná šířka", value: "full" },
                  ],
                  defaultValue: "1/4",
                  admin: {
                    layout: "horizontal",
                  },
                },
              ],
            },
          },
        },
        elements: [...elements, ...(additions.elements || [])],
        leaves: [...leaves, ...(additions.leaves || [])],
      },
    },
    overrides
  );

export default richText;
