import link from "../fields/link";
import { regeneratePage } from "../utilities/regeneratePage";
import removeLayout from "../utilities/removeLayout";
import type { GlobalConfig } from "payload/types";

export const Footer: GlobalConfig = {
  slug: "footer",
  label: "Patička",
  access: {
    read: () => true,
  },
  hooks: {
    afterRead: [
      ({ doc }) => {
        return removeLayout(doc);
      },
    ],
    afterChange: [
      ({ req: { payload } }) => {
        regeneratePage({
          payload,
        });
      },
    ],
  },
  fields: [
    {
      name: "columns",
      label: "Sloupce",
      labels: {
        singular: "Sloupec",
        plural: "Sloupce",
      },
      type: "array",
      minRows: 1,
      maxRows: 3,
      fields: [
        {
          name: "title",
          label: "Název",
          type: "text",
          required: true,
        },
        {
          name: "navItems",
          label: "Odkazy",
          labels: {
            singular: "Odkaz",
            plural: "Odkazy",
          },
          type: "array",
          fields: [
            link({
              appearances: false,
            }),
          ],
        },
      ],
    },
  ],
};
