import { MenuDescription } from "../blocks/MenuDescription";
import { MenuFeature } from "../blocks/MenuFeature";
import { MenuLink } from "../blocks/MenuLink";
import { MenuTitle } from "../blocks/MenuTitle";
import link from "../fields/link";
import { regeneratePage } from "../utilities/regeneratePage";
import removeLayout from "../utilities/removeLayout";
import { GlobalConfig } from "payload/types";

const menuColumnBlocks = [MenuTitle, MenuLink, MenuDescription, MenuFeature];

const Header: GlobalConfig = {
  slug: "header",
  label: "Hlavička",
  access: {
    read: () => true,
  },
  hooks: {
    afterRead: [
      ({ doc }) => {
        return removeLayout(doc);
      },
    ],
    afterChange: [
      ({ req: { payload } }) => {
        regeneratePage({
          payload,
        });
      },
    ],
  },
  fields: [
    {
      name: "items",
      label: "Položky",
      labels: {
        singular: "Položka",
        plural: "Položky",
      },
      type: "array",
      fields: [
        {
          name: "type",
          label: "Typ",
          type: "radio",
          defaultValue: "link",
          admin: {
            layout: "horizontal",
          },
          options: [
            {
              label: "Odkaz",
              value: "link",
            },
            {
              label: "Podnabídka",
              value: "subMenu",
            },
          ],
        },
        {
          name: "label",
          label: "Název odkazu",
          type: "text",
          required: true,
          admin: {
            width: "50%",
          },
        },
        {
          name: "icon",
          label: "Ikona",
          type: "upload",
          relationTo: "media",
        },
        {
          name: "children",
          label: "Odkazy",
          labels: {
            singular: "Odkaz",
            plural: "Odkazy",
          },
          type: "array",
          fields: [
            link({
              appearances: false,
              disableLabel: false,
            }),
          ],
          admin: {
            condition: (_, { type }) => type === "subMenu",
          },
        },
        link({
          appearances: false,
          disableLabel: true,
          disableIcon: true,
          overrides: {
            admin: {
              condition: (_, { type }) => type === "link",
            },
          },
        }),
      ],
    },
  ],
};

export default Header;
