import { regeneratePage } from "../utilities/regeneratePage";
import { GlobalConfig } from "payload/types";

const WebsiteSettings: GlobalConfig = {
  slug: "websiteSettings",
  label: "Nastavení webu",
  access: {
    read: () => {
      return true;
    },
  },
  hooks: {
    afterChange: [
      ({ req: { payload } }) => {
        regeneratePage({
          payload,
        });
      },
    ],
  },
  fields: [
    {
      name: "mainPage",
      label: "Hlavní stránka",
      type: "relationship",
      relationTo: ["pages"],
    },
    {
      name: "enableBanner",
      label: "Zobrazovat banner",
      type: "checkbox",
      defaultValue: false,
    },
    {
      name: "style", // required
      label: "Styl banneru",
      type: "radio", // required
      options: [
        // required
        {
          label: "Textový",
          value: "text",
        },
        {
          label: "Kontaktní údaje",
          value: "contact",
        },
      ],
      defaultValue: "text", // The first value in options.
      admin: {
        layout: "horizontal",
        condition: (data, siblingData) => {
          if (data.enableBanner) {
            return true;
          } else {
            return false;
          }
        },
      },
    },
    {
      name: "contentOfBanner",
      label: "Obsah banneru",
      type: "text",
      admin: {
        condition: (data, siblingData) => {
          if (data.enableBanner && data.style === "text") {
            return true;
          } else {
            return false;
          }
        },
      },
    },
  ],
};

export default WebsiteSettings;
