import checkDiskSpace from "check-disk-space";
import dotenv from "dotenv";
import express from "express";
import path from "path";
import payload from "payload";

dotenv.config();

const app = express();

app.get("/", (_, res) => {
  res.redirect("/admin");
});

app.get("/check-disk-space", (req, res) => {
  const isWin = process.platform === "win32";
  const path = isWin ? process.cwd() : "/";
  checkDiskSpace(path).then((diskSpace) => {
    res.json(diskSpace);
  });
});

app.use("/", express.static(path.resolve(__dirname, "./public")));

const start = async () => {
  await payload.init({
    secret: process.env.PAYLOAD_SECRET,
    mongoURL: process.env.MONGODB_URI,
    express: app,
    email: {
      transportOptions: {
        host: process.env.SMTP_HOST,
        auth: {
          user: process.env.SMTP_USER,
          pass: process.env.SMTP_PASS,
        },
        port: 465,
        secure: true,
        tls: {
          rejectUnauthorized: false,
        },
      },
      fromName: "Energo Savings",
      fromAddress: "no-reply@energosavings.cz",
    },
    onInit: async () => {
      payload.logger.info(`Payload Admin URL: ${payload.getAdminURL()}`);
    },
  });

  app.listen(3000);
};

start();
