import type { Page, WebsiteSetting } from "payload/generated-types";

export const deletePage = async ({
  doc,
  payload,
}: {
  doc?: any; // eslint-disable-line @typescript-eslint/no-explicit-any
  collection?: string;
  payload: any;
}): Promise<void> => {
  try {
    const websiteSettings: WebsiteSetting = await payload.findGlobal({
      slug: "websiteSettings", // required
    });
    const homepage = websiteSettings.mainPage.value as Page;
    const path = doc.slug === homepage.slug ? "/" : `/${doc.slug}`;
    const paths = [];
    paths.push(path);
    const res = await fetch(
      `${process.env.PAYLOAD_PUBLIC_APP_URL}/api/revalidate`,
      {
        method: "POST",
        body: JSON.stringify(paths),
        headers: {
          "Content-Type": "application/json",
        },
      }
    );
    if (res.ok) {
      payload.logger.info(`Revalidated`);
    } else {
      payload.logger.error(`Error revalidating`);
    }
  } catch (err: unknown) {
    payload.logger.error(`Error hitting revalidate route}`);
  }
};
