import type { Page, Post, WebsiteSetting } from "payload/generated-types";

export const regeneratePage = async ({
  payload,
}: {
  doc?: any; // eslint-disable-line @typescript-eslint/no-explicit-any
  collection?: string;
  payload: any;
}): Promise<void> => {
  try {
    const websiteSettings: WebsiteSetting = await payload.findGlobal({
      slug: "websiteSettings",
    });
    const homepage = websiteSettings.mainPage.value as Page;

    const posts: string[] = await payload
      .find({
        collection: "posts",
        pagination: false,
      })
      .then(({ docs }) =>
        docs.map((doc: Post) => {
          return `/blog/${doc.slug}`;
        })
      );

    const pages: string[] = await payload
      .find({
        collection: "pages",
        pagination: false,
      })
      .then(({ docs }) =>
        docs.map((doc: Page) => {
          if (doc.slug === homepage.slug) {
            return "/";
          }
          return `/${doc.slug}`;
        })
      );

    const employees: string[] = await payload
      .find({
        collection: "employees",
        pagination: false,
      })
      .then(({ docs }) =>
        docs.map((doc: Page) => {
          return `/employee/${doc.slug}`;
        })
      );
    const paths = posts.concat(pages, employees);

    const res = await fetch(
      `${process.env.PAYLOAD_PUBLIC_APP_URL}/api/revalidate`,
      {
        method: "POST",
        body: JSON.stringify(paths),
        headers: {
          "Content-Type": "application/json",
        },
      }
    );
    if (res.ok) {
      payload.logger.info(`Revalidated`);
    } else {
      payload.logger.error(`Error revalidating`);
    }
  } catch (err: unknown) {
    payload.logger.error(`Error hitting revalidate route}`);
  }
};
